@@ -15,8 +15,9 @@
 
 import logging
 
-from os_client_config import config
-from os_client_config import exceptions as occ_exceptions
+from openstack.config import exceptions as sdk_exceptions
+from openstack.config import loader as config
+
 from oslo_utils import strutils
 import six
 
@@ -93,8 +94,15 @@ class OSC_Config(config.OpenStackConfig):
             ]
             for prop in domain_props:
                 if config['auth'].pop(prop, None) is not None:
-                    LOG.warning("Ignoring domain related config " +
-                                prop + " because identity API version is 2.0")
+                    if config.get('cloud'):
+                        LOG.warning(
+                            "Ignoring domain related config %s for %s"
+                            "because identity API version is 2.0" % (
+                                prop, config['cloud']))
+                    else:
+                        LOG.warning(
+                            "Ignoring domain related config %s because"
+                            " identity API version is 2.0" % prop)
         return config
 
     def _auth_default_domain(self, config):
@@ -212,7 +220,7 @@ class OSC_Config(config.OpenStackConfig):
                 prompt_options.append(p_opt)
 
         if msgs:
-            raise occ_exceptions.OpenStackConfigException('\n'.join(msgs))
+            raise sdk_exceptions.OpenStackConfigException('\n'.join(msgs))
         else:
             for p_opt in prompt_options:
                 config['auth'][p_opt.dest] = self._pw_callback(p_opt.prompt)
